"use client";
import React, { useEffect, useState } from "react";
import PropTypes from "prop-types";
import Card from "@components/base/card";
import Pagination from "@components/top-level/pagination";
import { useSearchParams } from "next/navigation";
import styles from "./styles.module.css";

const BlogLists = ({ title, description, blogs }) => {
  const searchParams = useSearchParams();
  let searchPage = searchParams.get("page");
  console.log("iuh", searchPage);
  const length = blogs.length;
  const itemsPerPage = 6;
  const [currentPage, setCurrentPage] = useState(searchPage);
  // Calculate the start and end indices for the current page
  const startIndex = blogs.length > 6 ? (currentPage - 1) * itemsPerPage : 0;
  const endIndex = startIndex + itemsPerPage;
  const slicedData = blogs.slice(startIndex, endIndex);

  useEffect(() => {
    setCurrentPage(parseInt(searchPage));
  }, [searchPage]);
  // Handle page change
  const handlePageChange = (pageNumber) => {
    setCurrentPage(pageNumber);
    window.scrollTo({ top: 0, behavior: "smooth" });
  };

  return (
    <div className={styles["blog-container"]}>
      <h2 className={styles.title}>{title}</h2>
      <p className={styles.description}>{description}</p>
      <div className={styles.row}>
        {slicedData.map((blogData, i) => (
          <div key={i} className={styles.col}>
            <Card {...blogData} />
          </div>
        ))}
      </div>
      <div className={styles.pagination}>
        <Pagination
          currentPage={currentPage}
          total={length}
          perPage={itemsPerPage}
          onPageChange={handlePageChange}
        />
      </div>
    </div>
  );
};

BlogLists.propTypes = {
  title: PropTypes.string,
  description: PropTypes.string,
  blogs: PropTypes.array,
};

export default BlogLists;
